@@ -40,6 +40,7 @@
 
 using namespace emscripten;
 
+using namespace Stockfish;
 
 void initialize_stockfish() {
   pieceMap.init();
@@ -371,6 +372,7 @@ private:
       Board::sfInitialized = true;
     }
     v = get_variant(uciVariant);
+    UCI::init_variant(v);
     this->resetStates();
     if (fen == "")
       fen = v->startFen;
