@@ -1,11 +1,13 @@
-use url::Url;
-use std::time::Duration;
-use std::num::NonZeroU8;
-use shakmaty::fen::Fen;
-use shakmaty::uci::Uci;
+use std::{num::NonZeroU8, time::Duration};
+
+use shakmaty::{fen::Fen, uci::Uci};
 use tokio::sync::oneshot;
-use crate::api::{Score, LichessVariant, Work, BatchId, AnalysisPart};
-use crate::assets::EngineFlavor;
+use url::Url;
+
+use crate::{
+    api::{AnalysisPart, BatchId, LichessVariant, Score, Work},
+    assets::EngineFlavor,
+};
 
 /// Uniquely identifies a position within a batch.
 #[derive(Debug, Copy, Clone)]
@@ -19,7 +21,7 @@ pub struct Position {
     pub url: Option<Url>,
 
     pub variant: LichessVariant,
-    pub fen: Fen,
+    pub root_fen: Fen,
     pub moves: Vec<Uci>,
 }
 
@@ -42,7 +44,7 @@ impl PositionResponse {
     pub fn to_best(&self) -> AnalysisPart {
         AnalysisPart::Best {
             pv: self.pvs.best().cloned().unwrap_or_default(),
-            score: self.scores.best().cloned().expect("got score"),
+            score: self.scores.best().copied().expect("got score"),
             depth: self.depth,
             nodes: self.nodes,
             time: self.time.as_millis() as u64,
@@ -64,7 +66,7 @@ impl PositionResponse {
 
 #[derive(Debug, Clone)]
 pub struct Matrix<T> {
-    matrix: Vec<Vec<Option<T>>>
+    matrix: Vec<Vec<Option<T>>>,
 }
 
 impl<T> Matrix<T> {
@@ -84,7 +86,9 @@ impl<T> Matrix<T> {
     }
 
     pub fn best(&self) -> Option<&T> {
-        self.matrix.get(0).and_then(|row| row.last().and_then(|v| v.as_ref()))
+        self.matrix
+            .get(0)
+            .and_then(|row| row.last().and_then(|v| v.as_ref()))
     }
 }
 
@@ -100,7 +104,12 @@ pub struct Pull {
 }
 
 impl Pull {
-    pub fn split(self) -> (Option<Result<PositionResponse, PositionFailed>>, oneshot::Sender<Position>) {
+    pub fn split(
+        self,
+    ) -> (
+        Option<Result<PositionResponse, PositionFailed>>,
+        oneshot::Sender<Position>,
+    ) {
         (self.response, self.callback)
     }
 }
