@@ -15,7 +15,6 @@ use std::{
     cmp::min,
     env,
     path::PathBuf,
-    ptr,
     sync::Arc,
     thread,
     time::{Duration, Instant},
@@ -38,16 +37,8 @@ use crate::{
     util::RandomizedBackoff,
 };
 
-static COMPRESSED_DEPENDENCY_LIST: &[u8] = auditable::inject_dependency_list!();
-
 #[tokio::main(flavor = "current_thread")]
 async fn main() {
-    unsafe {
-        // Work around https://github.com/Shnatsel/rust-audit/issues/9.
-        // Safety: u8 is Copy.
-        ptr::read_volatile(&COMPRESSED_DEPENDENCY_LIST[0]);
-    }
-
     let opt = configure::parse_and_configure().await;
     let logger = Logger::new(opt.verbose, opt.command.map_or(false, Command::is_systemd));
 
@@ -101,7 +92,7 @@ async fn run(opt: Opt, logger: &Logger) {
         env::args().next().unwrap_or_else(|| "./fishnet".to_owned())
     ));
 
-    let cores = usize::from(opt.cores.unwrap_or(Cores::Auto));
+    let cores = opt.cores.unwrap_or(Cores::Auto).number();
     logger.info(&format!("Cores: {}", cores));
 
     // Install handler for SIGTERM.
@@ -156,8 +147,8 @@ async fn run(opt: Opt, logger: &Logger) {
     // to tx, thereby requesting more work.
     let mut rx = {
         let assets = Arc::new(assets);
-        let (tx, rx) = mpsc::channel::<Pull>(cores);
-        for i in 0..cores {
+        let (tx, rx) = mpsc::channel::<Pull>(cores.get());
+        for i in 0..cores.get() {
             let assets = assets.clone();
             let tx = tx.clone();
             let logger = logger.clone();
@@ -452,7 +443,7 @@ async fn auto_update(
         }
         logger.fishnet_info("Checking for updates (--auto-update) ...");
         self_update::backends::github::Update::configure()
-            .repo_owner("niklasf")
+            .repo_owner("lichess-org")
             .repo_name("fishnet")
             .bin_name("fishnet")
             .show_output(verbose)
