@@ -2,6 +2,7 @@ use std::{
     cmp::{max, min},
     collections::{hash_map::Entry, HashMap, VecDeque},
     convert::TryInto,
+    num::NonZeroUsize,
     sync::Arc,
     time::{Duration, Instant},
 };
@@ -10,7 +11,7 @@ use shakmaty::{
     fen::Fen,
     uci::{IllegalUciError, Uci},
     variant::VariantPosition,
-    CastlingMode, Position as _, PositionError,
+    CastlingMode, EnPassantMode, Position as _, PositionError,
 };
 use tokio::{
     sync::{mpsc, oneshot, Mutex, Notify},
@@ -33,7 +34,7 @@ use crate::{
 
 pub fn channel(
     opt: BacklogOpt,
-    cores: usize,
+    cores: NonZeroUsize,
     api: ApiStub,
     max_backoff: Duration,
     logger: Logger,
@@ -118,7 +119,7 @@ impl QueueStub {
 
 struct QueueState {
     shutdown_soon: bool,
-    cores: usize,
+    cores: NonZeroUsize,
     incoming: VecDeque<Position>,
     pending: HashMap<BatchId, PendingBatch>,
     move_submissions: VecDeque<CompletedBatch>,
@@ -127,7 +128,7 @@ struct QueueState {
 }
 
 impl QueueState {
-    fn new(cores: usize, logger: Logger) -> QueueState {
+    fn new(cores: NonZeroUsize, logger: Logger) -> QueueState {
         QueueState {
             shutdown_soon: false,
             cores,
@@ -284,7 +285,8 @@ impl QueueState {
                     if !pending.work.matrix_wanted() {
                         // Send partially analysis as progress report.
                         let progress_report = pending.progress_report();
-                        if progress_report.iter().filter(|p| p.is_some()).count() % (self.cores * 2)
+                        if progress_report.iter().filter(|p| p.is_some()).count()
+                            % (self.cores.get() * 2)
                             == 0
                         {
                             queue.api.submit_analysis(
@@ -518,7 +520,7 @@ impl IncomingBatch {
 
         let maybe_root_pos = VariantPosition::from_setup(
             body.variant.into(),
-            &body.position,
+            body.position.into_setup(),
             CastlingMode::Chess960,
         );
 
@@ -533,7 +535,7 @@ impl IncomingBatch {
             ),
         };
 
-        let root_fen = Fen::from_setup(&root_pos);
+        let root_fen = Fen(root_pos.clone().into_setup(EnPassantMode::Legal));
 
         let body_moves = {
             let mut moves = Vec::with_capacity(body.moves.len());
